<?php

class UbercartSTAPI extends AbstractSTAPI
{
	protected $noOrder = 'Your order could not be retrieved.';
	
	protected function handleError($message, $params) {
		drupal_set_message($message, 'error');
		drupal_goto('cart/checkout/review');
	}
	
	protected function processPayment($params) {
		$order = $this->retrieveOrder($params);
		
		$securitypostcode = isset($params['result']->securitypostcode) ? $params['result']->securitypostcode : '';
		$securitycode = isset($params['result']->securitycode) ? $params['result']->securitycode : '';
		$securityaddress = isset($params['result']->securityaddress) ? $params['result']->securityaddress : '';
		
		$comment = "
			<b><u>AVS Response</b></u><br />
			<b>Postcode:</b> $securitypostcode<br />
			<b>Address:</b> $securityaddress<br />
			<b>Security Code:</b> $securitycode<br />
		";
		
		uc_order_comment_save($order->order_id, 0, $comment, 'admin');
		uc_payment_enter($order->order_id, '2checkout', $order->order_total, 0, NULL, '');
		drupal_set_message(sprintf(t('Your order has been processed successfully.  Your Order ID is %d'), $params['order_id']), 'status');
		drupal_goto();
		exit;
	}
	
	protected function processPaymentFailure($params) {
		$order = $this->retrieveOrder($params);
		
		$comment = sprintf(t('This order failed.  Reason: %s.  See the SecureTrading log file (at time %s) for more information.'), $params['result']->errormessage, self::formatDate());
		
		uc_order_comment_save($order->order_id, 0, $comment, 'admin');
		uc_order_save($order);
		uc_order_update_status($params['order_id'], 'canceled');
	}
	
	protected function process3dSecure($params) {
		$this->processPayment($params);
	}
	
	protected function process3dSecureFailure($params) {
		$this->processPaymentFailure($params);
	}
	
	/**
	 * This class-specific method returns an order object upon success and returns void, sets an error message and redirects to the homepage upon failure.
	 */
	private function retrieveOrder($params) {
	
		if (!isset($params['order_id'])) {
			drupal_set_message($this->noOrder);
			drupal_goto();
			return;
		}
		
		$order = uc_order_load($params['order_id']);
		
		if ($order === FALSE || uc_order_status_data($order->order_status, 'state') != 'in_checkout') {
			drupal_set_message($this->noOrder);
			drupal_goto();
			return;
		}
		
		return $order;
	}
}

?>